---
name: Bug report
about: Create an issue for reporting bugs or errors faced
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
- [ ] Git cloned or downloaded the repo.
- [ ] Got credentials from spotify developer account.
- [ ] Install dependecies: `pip install -r requirements.txt`
- [ ] Youtube OAuth: `ytmusicapi oauth`
- [ ] Set environment variables by: '...'
- [ ] Command ran: '...'
- [ ] Got Error: '...'

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Device (please complete the following information):**
 - OS: [e.g. iOS]
 - Python Version: [e.g. Python 3.12.3 (got using `python -V`)]

**Additional context**
Add any other context about the problem here.
